@@ -28,14 +28,14 @@ class RPDevice:
             self.ch2_offset = float(calib_consts[2])
             self.ch2_gain = float(calib_consts[3])
         else:
-            self.ch1_offset = 0
-            self.ch1_gain = 1
-            self.ch2_offset = 0
-            self.ch2_gain = 1
+            self.ch1_offset = 0.
+            self.ch1_gain = 1.
+            self.ch2_offset = 0.
+            self.ch2_gain = 1.
         # Connection information
         self.address_port = ('rp-f05a98.local', 8900)
         # Device information
-        self.input_range_V = 2
+        self.input_range_V = 2.
         self.input_bits = 16
         # Socket thread
         self.client = rp.SocketClientThread()
@@ -125,7 +125,19 @@ class RPDevice:
         # Number of messages to use for data rate calculation
         n_samp = 10
 
-        t_start = time.time()
+        # Get reply from reply queue to obtain start time
+        client_reply = self.client.reply_q.get()
+
+        if client_reply.key == 'ERROR':
+            # End the thread if we receive ERROR
+            print(client_reply.reply)
+            self.client.join()
+            raise OSError('Error during RECEIVE: exiting')
+
+        elif client_reply.key == 'DATA':
+            # If we have DATA, get the start acquisition time
+            t_start = client_reply.reply['timestamp']
+
         t_prev = t_start
         i = 0
 
@@ -198,7 +210,19 @@ class RPDevice:
             self.client.join()
             raise OSError('Cannot calibrate when not connected to device')
 
-        t_start = time.time()
+        # Get reply from reply queue to obtain start time
+        client_reply = self.client.reply_q.get()
+
+        if client_reply.key == 'ERROR':
+            # End the thread if we receive ERROR
+            print(client_reply.reply)
+            self.client.join()
+            raise OSError('Error during RECEIVE: exiting')
+
+        elif client_reply.key == 'DATA':
+            # If we have DATA, get the start acquisition time
+            t_start = client_reply.reply['timestamp']
+
         t_prev = t_start
 
         ch1_data = []
@@ -224,10 +248,10 @@ class RPDevice:
                 # Otherwise, append data
                 ch1_data_no_calib = np.frombuffer(client_reply.reply['ch1_data'], dtype=np.int16)
                 ch2_data_no_calib = np.frombuffer(client_reply.reply['ch2_data'], dtype=np.int16)
-                ch1_data_calib = self.ch1_gain * (ch1_data_no_calib  * self.input_range_V / 2 ** self.input_bits + self.ch1_offset)
-                ch2_data_calib = self.ch2_gain * (ch2_data_no_calib * self.input_range_V / 2 ** self.input_bits + self.ch2_offset)
-                ch1_data.append(ch1_data_calib)
-                ch2_data.append(ch2_data_calib)
+                ch1_data_calib = self.ch1_gain * (ch1_data_no_calib * self.input_range_V / 2. ** self.input_bits + self.ch1_offset)
+                ch2_data_calib = self.ch2_gain * (ch2_data_no_calib * self.input_range_V / 2. ** self.input_bits + self.ch2_offset)
+                ch1_data = np.append(ch1_data, ch1_data_calib)
+                ch2_data = np.append(ch2_data, ch2_data_calib)
 
         # Save calibration data to files
         np.savetxt('red_pitaya_data_ch1_calib.txt', ch1_data)
